@@ -65,7 +65,7 @@
 					<form action="<?php echo esc_url( Akismet_Admin::get_page_url() ); ?>" method="POST">
 						<table cellspacing="0" class="akismet-settings">
 							<tbody>
-								<?php if ( !defined( 'WPCOM_API_KEY' ) ):?>
+								<?php if ( ! Akismet::predefined_api_key() ) { ?>
 								<tr>
 									<th class="akismet-api-key" width="10%" align="left" scope="row"><?php esc_html_e('API Key', 'akismet');?></th>
 									<td width="5%"/>
@@ -73,7 +73,7 @@
 										<span class="api-key"><input id="key" name="key" type="text" size="15" value="<?php echo esc_attr( get_option('wordpress_api_key') ); ?>" class="<?php echo esc_attr( 'regular-text code ' . $akismet_user->status ); ?>"></span>
 									</td>
 								</tr>
-								<?php endif; ?>
+								<?php } ?>
 								<?php if ( isset( $_GET['ssl_status'] ) ) { ?>
 									<tr>
 										<th align="left" scope="row"><?php esc_html_e( 'SSL Status', 'akismet' ); ?></th>
@@ -82,10 +82,7 @@
 											<p>
 												<?php
 
-												if ( ! function_exists( 'wp_http_supports' ) ) {
-													?><b><?php esc_html_e( 'Disabled.', 'akismet' ); ?></b> <?php printf( esc_html( 'Your WordPress installation does not include the function %s; upgrade to the latest version of WordPress.', 'akismet' ), '<code>wp_http_supports</code>' ); ?><?php
-												}
-												else if ( ! wp_http_supports( array( 'ssl' ) ) ) {
+												if ( ! wp_http_supports( array( 'ssl' ) ) ) {
 													?><b><?php esc_html_e( 'Disabled.', 'akismet' ); ?></b> <?php esc_html_e( 'Your Web server cannot make SSL requests; contact your Web host and ask them to add support for SSL requests.', 'akismet' ); ?><?php
 												}
 												else {
@@ -154,79 +151,92 @@
 										?>
 									</td>
 								</tr>
+								<tr>
+									<th class="comment-form-privacy-notice" align="left" scope="row"><?php esc_html_e('Privacy', 'akismet'); ?></th>
+									<td></td>
+									<td align="left">
+										<fieldset><legend class="screen-reader-text"><span><?php esc_html_e('Akismet privacy notice', 'akismet'); ?></span></legend>
+										<p><label for="akismet_comment_form_privacy_notice_display"><input type="radio" name="akismet_comment_form_privacy_notice" id="akismet_comment_form_privacy_notice_display" value="display" <?php checked('display', get_option('akismet_comment_form_privacy_notice')); ?> /> <?php esc_html_e('Display a privacy notice under your comment forms.', 'akismet'); ?></label></p>
+										<p><label for="akismet_comment_form_privacy_notice_hide"><input type="radio" name="akismet_comment_form_privacy_notice" id="akismet_comment_form_privacy_notice_hide" value="hide" <?php echo in_array( get_option('akismet_comment_form_privacy_notice'), array('display', 'hide') ) ? checked('hide', get_option('akismet_comment_form_privacy_notice'), false) : 'checked="checked"'; ?> /> <?php esc_html_e('Do not display privacy notice.', 'akismet'); ?></label></p>
+										</fieldset>
+										<span class="akismet-note"><?php esc_html_e( 'To help your site with transparency under privacy laws like the GDPR, Akismet can display a notice to your users under your comment forms. This feature is disabled by default, however, you can turn it on above.', 'akismet' );?></span>
+									</td>
+								</tr>
 							</tbody>
 						</table>
 						<div class="akismet-card-actions">
-							<?php if ( !defined( 'WPCOM_API_KEY' ) ):?>
+							<?php if ( ! Akismet::predefined_api_key() ) { ?>
 							<div id="delete-action">
 								<a class="submitdelete deletion" href="<?php echo esc_url( Akismet_Admin::get_page_url( 'delete_key' ) ); ?>"><?php esc_html_e('Disconnect this account', 'akismet'); ?></a>
 							</div>
-							<?php endif; ?>
+							<?php } ?>
 							<?php wp_nonce_field(Akismet_Admin::NONCE) ?>
 							<div id="publishing-action">
 								<input type="hidden" name="action" value="enter-key">
-								<input type="submit" name="submit" id="submit" class="akismet-button akismet-is-primary" value="<?php esc_attr_e('Save Changes', 'akismet');?>">
+								<input type="submit" name="submit" id="submit" class="akismet-button akismet-could-be-primary" value="<?php esc_attr_e('Save Changes', 'akismet');?>">
 							</div>
 							<div class="clear"></div>
 						</div>
 					</form>
 				</div>
 			</div>
-
-			<div class="akismet-card">
-				<div class="akismet-section-header">
-					<div class="akismet-section-header__label">
-						<span><?php esc_html_e( 'Account' , 'akismet'); ?></span>
+			
+			<?php if ( ! Akismet::predefined_api_key() ) { ?>
+				<div class="akismet-card">
+					<div class="akismet-section-header">
+						<div class="akismet-section-header__label">
+							<span><?php esc_html_e( 'Account' , 'akismet'); ?></span>
+						</div>
 					</div>
-				</div>
 				
-				<div class="inside">
-					<table cellspacing="0" border="0" class="akismet-settings">
-						<tbody>
-							<tr>
-								<th scope="row" align="left"><?php esc_html_e( 'Subscription Type' , 'akismet');?></th>
-								<td width="5%"/>
-								<td align="left">
-									<p><?php echo esc_html( $akismet_user->account_name ); ?></p>
-								</td>
-							</tr>
-							<tr>
-								<th scope="row" align="left"><?php esc_html_e( 'Status' , 'akismet');?></th>
-								<td width="5%"/>
-								<td align="left">
-									<p><?php 
-										if ( 'cancelled' == $akismet_user->status ) :
-											esc_html_e( 'Cancelled', 'akismet' ); 
-										elseif ( 'suspended' == $akismet_user->status ) :
-											esc_html_e( 'Suspended', 'akismet' );
-										elseif ( 'missing' == $akismet_user->status ) :
-											esc_html_e( 'Missing', 'akismet' ); 
-										elseif ( 'no-sub' == $akismet_user->status ) :
-											esc_html_e( 'No Subscription Found', 'akismet' );
-										else :
-											esc_html_e( 'Active', 'akismet' );  
-										endif; ?></p>
-								</td>
-							</tr>
-							<?php if ( $akismet_user->next_billing_date ) : ?>
-							<tr>
-								<th scope="row" align="left"><?php esc_html_e( 'Next Billing Date' , 'akismet');?></th>
-								<td width="5%"/>
-								<td align="left">
-									<p><?php echo date( 'F j, Y', $akismet_user->next_billing_date ); ?></p>
-								</td>
-							</tr>
-							<?php endif; ?>
-						</tbody>
-					</table>
-					<div class="akismet-card-actions">
-						<div id="publishing-action">
-							<?php Akismet::view( 'get', array( 'text' => ( $akismet_user->account_type == 'free-api-key' && $akismet_user->status == 'active' ? __( 'Upgrade' , 'akismet') : __( 'Change' , 'akismet') ), 'redirect' => 'upgrade' ) ); ?>
+					<div class="inside">
+						<table cellspacing="0" border="0" class="akismet-settings">
+							<tbody>
+								<tr>
+									<th scope="row" align="left"><?php esc_html_e( 'Subscription Type' , 'akismet');?></th>
+									<td width="5%"/>
+									<td align="left">
+										<p><?php echo esc_html( $akismet_user->account_name ); ?></p>
+									</td>
+								</tr>
+								<tr>
+									<th scope="row" align="left"><?php esc_html_e( 'Status' , 'akismet');?></th>
+									<td width="5%"/>
+									<td align="left">
+										<p><?php 
+											if ( 'cancelled' == $akismet_user->status ) :
+												esc_html_e( 'Cancelled', 'akismet' ); 
+											elseif ( 'suspended' == $akismet_user->status ) :
+												esc_html_e( 'Suspended', 'akismet' );
+											elseif ( 'missing' == $akismet_user->status ) :
+												esc_html_e( 'Missing', 'akismet' ); 
+											elseif ( 'no-sub' == $akismet_user->status ) :
+												esc_html_e( 'No Subscription Found', 'akismet' );
+											else :
+												esc_html_e( 'Active', 'akismet' );  
+											endif; ?></p>
+									</td>
+								</tr>
+								<?php if ( $akismet_user->next_billing_date ) : ?>
+								<tr>
+									<th scope="row" align="left"><?php esc_html_e( 'Next Billing Date' , 'akismet');?></th>
+									<td width="5%"/>
+									<td align="left">
+										<p><?php echo date( 'F j, Y', $akismet_user->next_billing_date ); ?></p>
+									</td>
+								</tr>
+								<?php endif; ?>
+							</tbody>
+						</table>
+						<div class="akismet-card-actions">
+							<div id="publishing-action">
+								<?php Akismet::view( 'get', array( 'text' => ( $akismet_user->account_type == 'free-api-key' && $akismet_user->status == 'active' ? __( 'Upgrade' , 'akismet') : __( 'Change' , 'akismet') ), 'redirect' => 'upgrade' ) ); ?>
+							</div>
+							<div class="clear"></div>
 						</div>
-						<div class="clear"></div>
 					</div>
 				</div>
-			</div>
+			<?php } ?>
 		<?php endif;?>
 	</div>
-</div>
\ No newline at end of file
+</div>
